@@ -4,13 +4,14 @@ from .iosxr_netconf import SCIOSXR
 from .junos import SCJunOS
 from .nxos import SCNXOS
 from .sros import SCNokiaSROSDriver
-from .srl_ssh import NokiaSRLSSHDriver
 from .srl import SCNokiaSRLDriver
 from .eos import SCEOSDriver
 from .nos import SCNOSDriver
 from .aoscx import SCAOSCXDriver
 from .waveserver import WaveServerDriver
 from .psimn import PSIMN
+from .rls import CienaRLS
+from .saos import SCCienaSAOS
 
 PLATFORM_MAP = {
     "iosxr": SCIOSXR_SSH,
@@ -18,13 +19,14 @@ PLATFORM_MAP = {
     "nxos": SCNXOS,
     "junos": SCJunOS,
     "sros": SCNokiaSROSDriver,
-    "srl_ssh": NokiaSRLSSHDriver,
     "srl": SCNokiaSRLDriver,
     "eos": SCEOSDriver,
     "nos": SCNOSDriver,
     "waveserver": WaveServerDriver,
     "aoscx": SCAOSCXDriver,
     "psimn": PSIMN,
+    "rls": CienaRLS,
+    "saos": SCCienaSAOS,
 }
 
 
