@@ -1,7 +1,8 @@
-from typing import Dict, List
+from typing import Dict, List, Optional
 import re
 from napalm.base import models as napalm_models
-from netmiko import ConnectHandler
+from netmiko.ssh_dispatcher import ConnectHandler, CLASS_MAPPER_BASE
+from netmiko import BaseConnection
 
 from . import models as sc_models
 
@@ -126,3 +127,47 @@ class SCBaseNetconfDriver(SCBaseDriver):
 
     def _iterfind(self, xml_tree, element):
         return getattr(xml_tree, "iterfind")(element, namespaces=self.NS)
+
+
+class SCBaseSSHDriver(SCBaseDriver):
+    """
+    Generic base netmiko driver for all the weird WAN platforms.
+    """
+    netmiko_host_type = None # set in child class if applicable
+
+    def __init__(
+        self,
+        hostname: str,
+        username: str,
+        password: str,
+        timeout: int = 60,
+        optional_args: Optional[Dict] = None,
+    ) -> None:
+        if optional_args is None:
+            optional_args = {}
+        self.hostname = hostname
+        self.username = username
+        self.password = password
+        self.timeout = timeout
+
+    def open(self):
+        
+        if CLASS_MAPPER_BASE.get(self.netmiko_host_type):
+            self.device = self._netmiko_open(self.netmiko_host_type)
+        else:
+            self.device = BaseConnection(
+            ip=self.hostname,
+            username=self.username,
+            password=self.password,
+            timeout=self.timeout,
+            
+        )
+
+    def close(self):
+        self._netmiko_close()
+
+    def send_command(self, cmd: str, read_timeout:int=10) -> str:
+        """
+        Sends command with netmiko and returns the result
+        """
+        return self.device.send_command(cmd, read_timeout=read_timeout)
\ No newline at end of file
