@@ -40,47 +40,42 @@ class SCEOSDriver(EOSDriver, SCBaseDriver):
             hostname, username, password, timeout=timeout, optional_args=optional_args
         )
 
-    def _get_optic_port(self, slot, model):
-        """
-        Certain ports on certain models need to have a "/1"
-        appended to each one.
-        """
-        if model == "DCS-7060X6-64PE" and int(slot) < 65:
-            return f"Ethernet{slot}/1"
-        if model == "DCS-7280DR3A-54":
-            return f"Ethernet{slot}/1"
-        if model == "DCS-7050SX3-48C8C" and int(slot) > 48:
-            return f"Ethernet{slot}/1"
-        if model == "DCS-7280SR3-40YC6" and int(slot) > 40:
-            return f"Ethernet{slot}/1"
-
-        return f"Ethernet{slot}"
 
     def get_inventory(self) -> List[InventoryDict]:
-        inventory = self._run_commands(["show inventory"], encoding="json")
 
+        output = self._run_commands(["show inventory", "show interface transceiver"], encoding="json")
+        inventory = output[0]
+
+        # 'show int transciever' gives us a mapping of the slot number that shows up
+        # in 'show inventory' to the name of the interface.
+        trans = output[1]["interfaces"]
+
+        slot_to_port = {}
+        for i_name, item in trans.items():
+            print(f"processing {i_name}")
+            if not item:
+                continue
+            slot = item["slot"].replace("Ethernet","")
+            if slot not in slot_to_port:
+                slot_to_port[slot] = i_name
         results = []
-
-        # luckily for us we get the device model with this call
-        # which we need to munge the name of the iterface
-        # the optic is on
-        model = inventory[0]["systemInformation"]["name"]
+        pprint(slot_to_port)
 
         ### optics
-        for slot, optic in inventory[0]["xcvrSlots"].items():
+        for slot, optic in inventory["xcvrSlots"].items():
             if optic.get("modelName"):
                 results.append(
                     {
                         "type": "optic",
                         "subtype": optic["modelName"],
-                        "name": self._get_optic_port(slot, model),
+                        "name": slot_to_port[slot],
                         "part_number": optic["modelName"],
                         "serial_number": optic["serialNum"],
                     },
                 )
 
         ### line cards
-        for slot, card in inventory[0]["cardSlots"].items():
+        for slot, card in inventory["cardSlots"].items():
             if card.get("serialNum"):
                 results.append(
                     {
@@ -93,7 +88,7 @@ class SCEOSDriver(EOSDriver, SCBaseDriver):
                 )
 
         ### PSUs
-        for slot, psu in inventory[0]["powerSupplySlots"].items():
+        for slot, psu in inventory["powerSupplySlots"].items():
             if psu.get("serialNum"):
                 results.append(
                     {
@@ -106,7 +101,7 @@ class SCEOSDriver(EOSDriver, SCBaseDriver):
                 )
 
         ### FANs
-        for slot, fan in inventory[0]["fanTraySlots"].items():
+        for slot, fan in inventory["fanTraySlots"].items():
             if fan.get("serialNum"):
                 results.append(
                     {
